# -*- coding: utf-8 -*- 
from .version import __version__  # noqa
from .ffsubsync import main  # noqa
